package com.ruoyi.ems.service.impl;

import com.ruoyi.ems.domain.CoChargingConfig;
import com.ruoyi.ems.mapper.CoChargingConfigMapper;
import com.ruoyi.ems.service.ICoChargingConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 商户能源计费配置Service业务层处理
 *
 * @author ruoyi
 * @date 2024-08-26
 */
@Service
public class CoChargingConfigServiceImpl implements ICoChargingConfigService {
    @Autowired
    private CoChargingConfigMapper coChargingConfigMapper;

    /**
     * 查询商户能源计费配置
     *
     * @param id 商户能源计费配置主键
     * @return 商户能源计费配置
     */
    @Override
    public CoChargingConfig selectCoChargingConfigById(Long id) {
        return coChargingConfigMapper.selectCoChargingConfigById(id);
    }

    @Override
    public CoChargingConfig selectByArea(String areaCode) {
        return coChargingConfigMapper.selectByArea(areaCode);
    }

    /**
     * 查询商户能源计费配置列表
     *
     * @param admCoChargingConfig 商户能源计费配置
     * @return 商户能源计费配置
     */
    @Override
    public List<CoChargingConfig> selectCoChargingConfigList(CoChargingConfig admCoChargingConfig) {
        return coChargingConfigMapper.selectCoChargingConfigList(admCoChargingConfig);
    }

    /**
     * 新增商户能源计费配置
     *
     * @param coChargingConfig 商户能源计费配置
     * @return 结果
     */
    @Override
    public int insertCoChargingConfig(CoChargingConfig coChargingConfig) {
        return coChargingConfigMapper.insertCoChargingConfig(coChargingConfig);
    }

    /**
     * 修改商户能源计费配置
     *
     * @param coChargingConfig 商户能源计费配置
     * @return 结果
     */
    @Override
    public int updateCoChargingConfig(CoChargingConfig coChargingConfig) {
        return coChargingConfigMapper.updateCoChargingConfig(coChargingConfig);
    }

    /**
     * 批量删除商户能源计费配置
     *
     * @param ids 需要删除的商户能源计费配置主键
     * @return 结果
     */
    @Override
    public int deleteCoChargingConfigByIds(Long[] ids) {
        return coChargingConfigMapper.deleteCoChargingConfigByIds(ids);
    }

    /**
     * 删除商户能源计费配置信息
     *
     * @param id 商户能源计费配置主键
     * @return 结果
     */
    @Override
    public int deleteCoChargingConfigById(Long id) {
        return coChargingConfigMapper.deleteCoChargingConfigById(id);
    }
}
